import"./outputWidgets.b703ca45.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="11ea4bed-33ef-40cb-9e85-c83de5b29ae5",e._sentryDebugIdIdentifier="sentry-dbid-11ea4bed-33ef-40cb-9e85-c83de5b29ae5")}catch{}})();function d(e,n,o=!1,t=!0){const r=(t?e.toLocaleLowerCase():e).replace(/[^a-zA-Z0-9]/g,"_"),c=o?r:r.replace(/_+/g,"_");return n?c:c.replace(/_$/,"")}function l(e){var r;const o=e.toLocaleLowerCase().trim().normalize("NFD").replace(/[\u0300-\u036f]/g,""),t=/[a-z0-9]+/g,a=o.match(t);return(r=a==null?void 0:a.join("-"))!=null?r:""}export{l as a,d as n};
//# sourceMappingURL=string.b7af0a8a.js.map
