import{Q as d}from"./outputWidgets.b703ca45.js";import{c as s,d as i}from"./index.80dd93e0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="372752ca-6da6-4d35-88f7-cce8874de190",e._sentryDebugIdIdentifier="sentry-dbid-372752ca-6da6-4d35-88f7-cce8874de190")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:o,RangePicker:c}=s(i),g=d(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:c,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(c.name,c),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{g as D,t as M,o as Q,c as R,r as W};
//# sourceMappingURL=dayjs.e3a576d3.js.map
