import"./outputWidgets.b703ca45.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="fb71a8cc-1b85-4e79-9bc5-22907ca7864b",e._sentryDebugIdIdentifier="sentry-dbid-fb71a8cc-1b85-4e79-9bc5-22907ca7864b")}catch{}})();const b=e=>{try{return new URL(e),!0}catch{return!1}};export{b as i};
//# sourceMappingURL=url.7a748c18.js.map
