import{a as e,A as t,B as s}from"./Text.4646803d.js";import{A as o}from"./Link.b9370a79.js";import{a as r,A as i}from"./Title.c76d824d.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[n]="a2cad2a1-0500-4b16-840f-843de6e9b240",a._sentryDebugIdIdentifier="sentry-dbid-a2cad2a1-0500-4b16-840f-843de6e9b240")}catch{}})();e.Text=t;e.Title=r;e.Paragraph=i;e.Link=o;e.Base=s;e.install=function(a){return a.component(e.name,e),a.component(e.Text.displayName,t),a.component(e.Title.displayName,r),a.component(e.Paragraph.displayName,i),a.component(e.Link.displayName,o),a};
//# sourceMappingURL=index.006cef5c.js.map
