import{d as m,ez as c,u as e,b as d,c as u,et as y,f as o,w as a,be as _,ao as p,ev as g,e as b,eB as x}from"./outputWidgets.b703ca45.js";import"./router.c2e4e322.js";import"./jwt-decode.esm.74bd4619.js";import"./index.58a6f7ec.js";import{O as w}from"./organization.a1bd0b97.js";import{a as h}from"./asyncComputed.557fdbc3.js";import{a as k}from"./Title.c76d824d.js";import{A as B}from"./index.44c0d841.js";import{A}from"./index.1f3efcfb.js";import{A as C}from"./Text.4646803d.js";import{C as I}from"./Card.3c731ead.js";import"./FormItem.39e0b98f.js";import"./hasIn.66135dec.js";import"./storage.4f0beb94.js";import"./index.cd3799ce.js";import"./index.cf4c23b9.js";import"./record.6a34e5b4.js";import"./pubsub.781c61cb.js";import"./TabPane.9316e440.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="0b0be1d4-525f-43d5-9131-f8dee8f233a1",t._sentryDebugIdIdentifier="sentry-dbid-0b0be1d4-525f-43d5-9131-f8dee8f233a1")}catch{}})();const v={key:1},z={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},X=m({__name:"Billing",setup(t){const n=c().params.organizationId,{loading:f,result:l}=h(()=>w.get(n));return(D,T)=>e(f)?(d(),u(e(_),{key:0})):(d(),y("div",v,[o(e(B),{justify:"space-between",align:"center"},{default:a(()=>[o(e(k),{level:3},{default:a(()=>[p("Current plan")]),_:1}),g("",!0)]),_:1}),o(e(A),{style:{"margin-top":"0"}}),o(e(I),{style:{width:"300px"}},{default:a(()=>{var i,s;return[o(e(C),{type:"secondary"},{default:a(()=>[p("Plan")]),_:1}),b("div",z,x((s=(i=e(l))==null?void 0:i.billingMetadata)==null?void 0:s.plan),1)]}),_:1})]))}});export{X as default};
//# sourceMappingURL=Billing.969f5cab.js.map
