import{cu as d}from"./outputWidgets.b703ca45.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="19c50ee4-5705-4227-a756-13d9906d4c51",e._sentryDebugIdIdentifier="sentry-dbid-19c50ee4-5705-4227-a756-13d9906d4c51")}catch{}})();const t=(e,r)=>{d.error({message:e,description:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.41be47f9.js.map
