import{F as t}from"./Form.44bc3190.js";import{aJ as r,cj as n}from"./outputWidgets.b703ca45.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b6ec400b-e357-4914-85fe-c481d1e294b9",e._sentryDebugIdIdentifier="sentry-dbid-b6ec400b-e357-4914-85fe-c481d1e294b9")}catch{}})();t.useInjectFormItemContext=r;t.ItemRest=n;t.install=function(e){return e.component(t.name,t),e.component(t.Item.name,t.Item),e.component(n.name,n),e};
//# sourceMappingURL=index.e481fd6a.js.map
