import{v as h,w as k}from"./icons.5202cd65.js";import{d as _,F as y,b as a,et as t,e as o,bo as f,eA as S,ex as m,eB as v,t as g,E as I,u as b,ev as r,f as R,I as N,c as w,eC as C,eD as $}from"./outputWidgets.b703ca45.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[i]="aae8fe67-b432-41d9-818f-4c1e3b7d2fe9",s._sentryDebugIdIdentifier="sentry-dbid-aae8fe67-b432-41d9-818f-4c1e3b7d2fe9")}catch{}})();const B={class:"sidebar-content"},E={class:"section"},D=["onClick"],P={class:"item-title"},U=_({__name:"Sidebar",props:{currentRuntime:{},displaySidebar:{type:Boolean},forceResponsivity:{}},emits:["selectRuntime","closeSidebar"],setup(s,{emit:i}){const c=s,u=e=>{p(e.id)||i("selectRuntime",e)},l=y(()=>c.currentRuntime.sidebar.filter(e=>e.visible)),p=e=>e===c.currentRuntime.id;return(e,n)=>(a(),t("div",{class:m(["sidebar",e.forceResponsivity,{open:e.displaySidebar}])},[o("div",B,[o("div",E,[(a(!0),t(f,null,S(l.value,d=>(a(),t("div",{key:d.id,class:m(["item",{active:p(d.id)}]),onClick:K=>u(d)},[o("div",P,v(d.name),1)],10,D))),128))])])],2))}});const V=g(U,[["__scopeId","data-v-14a5ac8c"]]),F=s=>(C("data-v-e67cfd1a"),s=s(),$(),s),z={class:"left-side"},A=["d"],L={key:1,class:"brand"},j=["src"],q={key:1,class:"brand-name"},G=F(()=>o("div",null,null,-1)),H={key:0,class:"signed-email"},J=_({__name:"PlayerNavbar",props:{runtime:{},userEmail:{},forceResponsivity:{}},emits:["logout","navigate"],setup(s,{emit:i}){const c=s,u=I({displaySidebar:!1}),l=y(()=>{const e=c.runtime.sidebar;return!e||e.length==0?!1:e.some(n=>n.visible)}),p=e=>i("navigate",e);return(e,n)=>(a(),t(f,null,[l.value||e.runtime.logoUrl||e.runtime.brandName||e.userEmail?(a(),t("div",{key:0,class:m(["navbar",l.value&&"background"])},[o("div",z,[l.value?(a(),t("svg",{key:0,class:m(["sidebar-menu-icon",e.forceResponsivity]),viewBox:"0 0 24 24",fill:"var(--color-main)",onClick:n[0]||(n[0]=d=>u.displaySidebar=!u.displaySidebar)},[o("path",{d:b(h)},null,8,A)],2)):r("",!0),e.runtime.logoUrl||e.runtime.brandName?(a(),t("div",L,[e.runtime.logoUrl?(a(),t("img",{key:0,src:e.runtime.logoUrl,class:"logo-image"},null,8,j)):r("",!0),e.runtime.brandName?(a(),t("p",q,v(e.runtime.brandName),1)):r("",!0)])):r("",!0)]),G,e.userEmail?(a(),t("div",H,[o("span",null,v(e.userEmail),1),R(N,{width:"20",height:"20",class:"logout",path:b(k),fill:"var(--color-main)",onClick:n[1]||(n[1]=d=>i("logout"))},null,8,["path"])])):r("",!0)],2)):r("",!0),l.value?(a(),w(V,{key:1,"current-runtime":e.runtime,"display-sidebar":u.displaySidebar,"force-responsivity":e.forceResponsivity,onSelectRuntime:p},null,8,["current-runtime","display-sidebar","force-responsivity"])):r("",!0)],64))}});const Q=g(J,[["__scopeId","data-v-e67cfd1a"]]);export{Q as P};
//# sourceMappingURL=PlayerNavbar.6e90d633.js.map
