import{z as t}from"./index.cf4c23b9.js";import{w as s}from"./metadata.02d96d32.js";import"./outputWidgets.b703ca45.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="edb02070-03d8-4744-9e9e-f47cbd1a44a1",e._sentryDebugIdIdentifier="sentry-dbid-edb02070-03d8-4744-9e9e-f47cbd1a44a1")}catch{}})();const a=s.stages.flatMap(e=>e.transitions.flatMap(n=>n.typeName)),r=t.object({type:t.enum(["forms","hooks","jobs","scripts","conditions","iterators"]),id:t.string(),title:t.string(),position:t.object({x:t.number(),y:t.number()}),props:t.object({path:t.string().nullable(),filename:t.string().nullable(),variableName:t.string().nullable()})}),o=t.object({id:t.string(),type:t.enum(a),sourceStageId:t.string(),targetStageId:t.string(),props:t.object({conditionValue:t.string().nullable()})}),c=t.object({stages:t.array(r),transitions:t.array(o)});export{c as s};
//# sourceMappingURL=schema.9c38a07b.js.map
