import{C as t,E as d,K as i,a as f,M as b,c,P as l,R as y,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.9a97398c.js";import"./outputWidgets.b703ca45.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="07b5ffbb-66ed-4722-8b5a-f5dcc6637e7c",e._sentryDebugIdIdentifier="sentry-dbid-07b5ffbb-66ed-4722-8b5a-f5dcc6637e7c")}catch{}})();export{t as CancellationTokenSource,d as Emitter,i as KeyCode,f as KeyMod,b as MarkerSeverity,c as MarkerTag,l as Position,y as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.804dd343.js.map
