var o=Object.defineProperty;var i=(e,t,r)=>t in e?o(e,t,{enumerable:!0,configurable:!0,writable:!0,value:r}):e[t]=r;var a=(e,t,r)=>(i(e,typeof t!="symbol"?t+"":t,r),r);import{g as c,h as f,_ as d}from"./outputWidgets.b703ca45.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ed2fe631-6d70-4298-8fe6-e3c19fd8ef39",e._sentryDebugIdIdentifier="sentry-dbid-ed2fe631-6d70-4298-8fe6-e3c19fd8ef39")}catch{}})();const u=[{path:"/:path(.*)*",name:"player",component:()=>d(()=>import("./Player.147aab88.js"),["assets/Player.147aab88.js","assets/FormRunner.5f682dae.js","assets/outputWidgets.b703ca45.js","assets/outputWidgets.bd537527.css","assets/url.7a748c18.js","assets/storage.4f0beb94.js","assets/pubsub.781c61cb.js","assets/jwt-decode.esm.74bd4619.js","assets/icons.5202cd65.js","assets/CircularLoading.63631aeb.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.6e90d633.js","assets/PlayerNavbar.ead94b03.css","assets/ActionButton.7497460f.js","assets/ActionButton.f74e60ec.css","assets/WidgetsFrame.a8d8fb77.js","assets/WidgetsFrame.97ae601d.css","assets/index.5fc087d9.js","assets/Card.3c731ead.js","assets/TabPane.9316e440.js","assets/hasIn.66135dec.js","assets/index.006cef5c.js","assets/Text.4646803d.js","assets/Link.b9370a79.js","assets/Title.c76d824d.js","assets/FormRunner.8ff3f1ac.css","assets/uuid.2b259c22.js","assets/asyncComputed.557fdbc3.js","assets/Player.6fed9080.css"])}],g=c({history:f("/"),routes:u,scrollBehavior(e){if(e.hash)return{el:e.hash}}});async function w(){const e=await fetch("/_settings");if(!e.ok)throw new Error(await e.text());const t=await e.json();await s.init(t)}const n=class{constructor(t){this.config=t}static async init(t){n.instance=new n(t)}get showWatermark(){return this.config.show_watermark}get isStagingRelease(){return{}.VITE_ABSTRA_RELEASE==="staging"}get isLocal(){return location.origin.match(/http:\/\/localhost:\d+/)}};let s=n;a(s,"instance",null);export{s as S,g as a,u as r,w as s};
//# sourceMappingURL=index.d4bb89c7.js.map
