import"./outputWidgets.b703ca45.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4c173363-77bc-4f1b-8d72-41af22a4d38b",e._sentryDebugIdIdentifier="sentry-dbid-4c173363-77bc-4f1b-8d72-41af22a4d38b")}catch{}})();function n(e,t){return e.toLocaleString(void 0,{hour12:!1,timeZoneName:"short",day:"2-digit",month:"2-digit",year:"numeric",hour:"2-digit",minute:"2-digit",second:"2-digit",weekday:"long",...t})}export{n as g};
//# sourceMappingURL=datetime.998b4395.js.map
