import{S as p}from"./Sidebar.a09b3976.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.a39b7838.js";import{G as d,H as l,I as u}from"./icons.5202cd65.js";import{d as b,ez as f,F as g,a as _,b as y,c as v,w as r,f as a}from"./outputWidgets.b703ca45.js";import{a as z}from"./asyncComputed.557fdbc3.js";import"./router.c2e4e322.js";import"./jwt-decode.esm.74bd4619.js";import"./index.58a6f7ec.js";import{O as w}from"./organization.a1bd0b97.js";import{B as I}from"./BaseLayout.43d7cddc.js";import"./index.5255b475.js";import"./logo.084e5d7c.js";import"./Text.4646803d.js";import"./index.f858e58b.js";import"./FormItem.39e0b98f.js";import"./hasIn.66135dec.js";import"./storage.4f0beb94.js";import"./index.cd3799ce.js";import"./index.cf4c23b9.js";import"./record.6a34e5b4.js";import"./pubsub.781c61cb.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="5dc55d9b-62dd-4e49-8934-19ef01f1cbc2",o._sentryDebugIdIdentifier="sentry-dbid-5dc55d9b-62dd-4e49-8934-19ef01f1cbc2")}catch{}})();const K=b({__name:"Organization",setup(o){const n=f().params.organizationId,{result:t}=z(()=>w.get(n)),i=g(()=>t.value?[{label:"My organizations",path:"/organizations"},{label:t.value.name,path:`/organizations/${t.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing"}]}];return(h,B)=>{const m=_("router-view");return y(),v(I,null,{navbar:r(()=>[a(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:r(()=>[a(p,{class:"sidebar",sections:s})]),content:r(()=>[a(m)]),_:1})}}});export{K as default};
//# sourceMappingURL=Organization.60ce6963.js.map
