import{d as m,es as v,E as y,b as d,et as l,e as c,u as g,eu as r,dm as u,ev as w,ew as h,ex as S,t as b,r as k,a as C,f as p,w as I,bo as x}from"./outputWidgets.b703ca45.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="7a2086bb-c6b2-493a-97d1-fee58f2f6bf4",e._sentryDebugIdIdentifier="sentry-dbid-7a2086bb-c6b2-493a-97d1-fee58f2f6bf4")}catch{}})();const D=m({__name:"Modal",props:{containerStyle:{},headerStyle:{},contentStyle:{}},emits:["open","close"],setup(e,{expose:s,emit:o}){const i=v(),_=()=>{a.isOpened=!0,o("open")},n=()=>{a.isOpened=!1,o("close")};s({open:_,close:n});const a=y({isOpened:!1});return(t,f)=>(d(),l("div",{class:S(["background",a.isOpened&&"visible"]),onClick:n},[c("div",{class:"container",style:r(t.containerStyle),onClick:f[0]||(f[0]=h(()=>{},["stop"]))},[g(i).header?(d(),l("div",{key:0,class:"header",style:r(t.headerStyle)},[u(t.$slots,"header",{},void 0,!0)],4)):w("",!0),c("div",{class:"content",style:r(t.contentStyle)},[u(t.$slots,"content",{},void 0,!0)],4)],4)],2))}});const M=b(D,[["__scopeId","data-v-4d878495"]]),O=["src"],B=m({__name:"Home",setup(e){const s=y({onboardingForm:""}),o=k(null);return(i,_)=>{const n=C("router-view");return d(),l(x,null,[p(n,{class:"router"}),p(M,{ref_key:"modal",ref:o},{content:I(()=>[c("iframe",{class:"form",src:s.onboardingForm},null,8,O)]),_:1},512)],64)}}});const F=b(B,[["__scopeId","data-v-7e290e34"]]);export{F as default};
//# sourceMappingURL=Home.64798dbf.js.map
