import{d as h,ey as w,ez as y,r as k,F as x,b as n,c as d,w as t,et as b,eA as I,u as l,bd as C,ex as f,f as s,I as B,ao as N,eB as D,bo as S,bf as V,t as A,eC as L,eD as T,e as g,a as p,ev as E}from"./outputWidgets.b703ca45.js";import{h as $,s as z}from"./icons.5202cd65.js";import{_ as F}from"./logo.084e5d7c.js";import{B as H}from"./BaseLayout.43d7cddc.js";import{N as M}from"./NavbarControls.5db01344.js";import{c as R}from"./index.f858e58b.js";import"./asyncComputed.557fdbc3.js";import"./index.d4bb89c7.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.69b7b47b.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.5d19209c.js";import"./ant-design.db871477.js";import"./index.dfe99d95.js";import"./Modal.c03e4b0a.js";import"./storage.4f0beb94.js";import"./Link.b9370a79.js";import"./Text.4646803d.js";import"./index.006cef5c.js";import"./Title.c76d824d.js";import"./index.c55859fc.js";import"./workspaces.ac64317a.js";import"./record.6a34e5b4.js";import"./pubsub.781c61cb.js";import"./url.7a748c18.js";import"./popupNotifcation.41be47f9.js";import"./CircularLoading.63631aeb.js";import"./index.44c0d841.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="8785485f-2c0c-4ae3-a641-7ad8a45dfd70",e._sentryDebugIdIdentifier="sentry-dbid-8785485f-2c0c-4ae3-a641-7ad8a45dfd70")}catch{}})();const W=h({__name:"Sidebar",setup(e){var m;const o=w(),c=y(),r=k((m=c.name)!=null?m:"forms"),u=x(()=>[{name:"Home",icon:$,path:"home"},{name:"Settings",icon:z,path:"settings"}]),i=_=>{o.push(_.path),r.value=_.path};return(_,Q)=>(n(),d(l(V),{"inline-collapsed":""},{default:t(()=>[(n(!0),b(S,null,I(u.value,a=>(n(),d(l(C),{key:a.name,role:"button",class:f({active:r.value===a.path}),tabindex:"0",onClick:U=>i(a)},{icon:t(()=>[s(B,{class:f({active:r.value===a.path}),path:a.icon,width:"20",height:"20"},null,8,["class","path"])]),title:t(()=>[N(D(a.name),1)]),_:2},1032,["class","onClick"]))),128))]),_:1}))}});const P={},v=e=>(L("data-v-81cd596e"),e=e(),T(),e),j={class:"logo"},q=v(()=>g("img",{src:F,alt:"Abstra cloud logo"},null,-1)),G=v(()=>g("span",null," Abstra ",-1)),J=[q,G];function K(e,o){return n(),b("div",j,J)}const O=A(P,[["render",K],["__scopeId","data-v-81cd596e"]]),xe=h({__name:"Workspace",setup(e){return(o,c)=>{const r=p("ant-button"),u=p("router-link"),i=p("router-view");return n(),d(H,null,{navbar:t(()=>[s(l(R),{style:{padding:"5px 25px"}},{title:t(()=>[s(O)]),extra:t(()=>[s(M,{"show-github-stars":""},{default:t(()=>[E("",!0)]),_:1})]),_:1})]),sidebar:t(()=>[s(W,{class:"sidebar"})]),content:t(()=>[s(i)]),_:1})}}});export{xe as default};
//# sourceMappingURL=Workspace.cd935e52.js.map
