import"./outputWidgets.b703ca45.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="35e8cd6d-5ca6-4d7f-bf4a-f4aa29d0c765",x._sentryDebugIdIdentifier="sentry-dbid-35e8cd6d-5ca6-4d7f-bf4a-f4aa29d0c765")}catch{}})();const t=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{t as u};
//# sourceMappingURL=uuid.2b259c22.js.map
