import{t as n,b as s,et as d}from"./outputWidgets.b703ca45.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="36bd48f7-74e5-4e6b-9970-cf17de7493db",e._sentryDebugIdIdentifier="sentry-dbid-36bd48f7-74e5-4e6b-9970-cf17de7493db")}catch{}})();const o={},r={class:"organization-settings"};function i(e,t){return s(),d("div",r,"Organization settings")}const f=n(o,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.142609a0.js.map
