import{N as b}from"./NavbarControls.5db01344.js";import{d as _,ey as f,ez as y,F as g,a as v,b as c,et as h,f as e,w as s,u as a,e as k,bo as w,ao as S,c as x,eS as T,t as q}from"./outputWidgets.b703ca45.js";import{A as C}from"./Text.4646803d.js";import{T as I,A as o}from"./TabPane.9316e440.js";import{c as A}from"./index.f858e58b.js";import"./asyncComputed.557fdbc3.js";import"./index.d4bb89c7.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.69b7b47b.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.5d19209c.js";import"./ant-design.db871477.js";import"./index.dfe99d95.js";import"./Modal.c03e4b0a.js";import"./storage.4f0beb94.js";import"./Link.b9370a79.js";import"./index.006cef5c.js";import"./Title.c76d824d.js";import"./index.c55859fc.js";import"./workspaces.ac64317a.js";import"./record.6a34e5b4.js";import"./pubsub.781c61cb.js";import"./url.7a748c18.js";import"./popupNotifcation.41be47f9.js";import"./CircularLoading.63631aeb.js";import"./icons.5202cd65.js";import"./index.44c0d841.js";import"./hasIn.66135dec.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="d3cfca55-bd93-4d99-a67d-3453442022b8",r._sentryDebugIdIdentifier="sentry-dbid-d3cfca55-bd93-4d99-a67d-3453442022b8")}catch{}})();const B={class:"content"},D=_({__name:"Settings",setup(r){const t=f(),n=y();function m(){t.push({name:"home"})}const p=g(()=>{switch(n.name){case"settingsStyle":return"style";case"settingsSidebar":return"sidebar";case"settingsRequirements":return"requirements";default:return}});function d(i){switch(i){case"style":t.push({name:"settingsStyle"});break;case"sidebar":t.push({name:"settingsSidebar"});break;case"requirements":t.push({name:"settingsRequirements"});break}}return(i,N)=>{const u=v("router-view");return c(),h(w,null,[e(a(A),{style:{padding:"5px 25px"},onBack:m},{extra:s(()=>[e(b,{"show-v-s-code-button":"","show-save-button":""})]),avatar:s(()=>[e(a(C),null,{default:s(()=>[S("Settings")]),_:1})]),footer:s(()=>[e(a(I),{"active-key":p.value,onChange:d},{default:s(()=>[e(a(o),{key:"style",tab:"Style"}),e(a(o),{key:"sidebar",tab:"Sidebar"}),e(a(o),{key:"requirements",tab:"Requirements"})]),_:1},8,["active-key"])]),_:1}),k("div",B,[e(u,null,{default:s(({Component:l})=>[(c(),x(T(l)))]),_:1})])],64)}}});const oe=q(D,[["__scopeId","data-v-772f4b10"]]);export{oe as default};
//# sourceMappingURL=Settings.075e526b.js.map
